@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '5.046';
+our $VERSION = '5.052';
 
 sub new {
     my ($class) = @_;
@@ -207,12 +207,29 @@ sub PT::ClassBlock::X {
             return bless $hashRef, $class;
         }
     ';
+
+    my $errorLBrace = $class->{ErrorLBrace}->X($className);
     my $classGroups = $class->{ClassGroups}->X($className);
+    my $errorRBrace = $class->{ErrorRBrace}->X($className);
 
     $classBlock .= $classGroups;
     return $classBlock;
 }
 
+sub PT::ErrorLBrace::X {
+    my ($class, $className) = @_;
+
+    return (       $class->{LBrace}
+                || $class->{LBraceError} )->X($className);
+}
+
+sub PT::ErrorRBrace::X {
+    my ($class, $className) = @_;
+
+    return (       $class->{RBrace}
+                || $class->{RBraceError} )->X($className);       
+}
+
 sub PT::ClassGroups::X {
     my ($class, $className) = @_;
 
@@ -234,6 +251,7 @@ sub PT::Group::X {
                 || $class->{ImplementFunction}
                 || $class->{EmbedBlock}
                 || $class->{Function}
+                || $class->{GroupDeclaration}
                 || $class->{NonSyntaxClass} )->X($className);
 }
 
@@ -1042,8 +1060,7 @@ sub PT::VariableDeclaration::X {
     my ($class, $className) = @_;
     return (       $class->{ScalarDeclaration}
                 || $class->{ArrayDeclaration}
-                || $class->{HashDeclaration}
-                || $class->{GroupDeclaration} )->X($className);
+                || $class->{HashDeclaration} )->X($className);
 }
 
 sub PT::GroupDeclaration::X {
@@ -1054,7 +1071,7 @@ sub PT::GroupDeclaration::X {
 
     $groupTable->{$groupName} = {};
     for my $element (@groupElements) {
-        $groupTable->{$groupName}->{$element} = "";
+        $groupTable->{$className}->{$groupName}->{$element} = "";
     }
 
     my $groupElementsList = "";
@@ -1105,11 +1122,11 @@ sub PT::MakeGroup::X {
 
     my $groupName = $class->{GroupName}->X($className);
     my $groupNameObject = $class->{GroupNameObject}->X($className);
-    my @groupElements = keys %{ $groupTable->{$groupName} };
+    my @groupElements = keys %{ $groupTable->{$className}->{$groupName} };
 
     # if(exists $groupTable->{groupNameObject}) {};
 
-    my $makeGroup = "my " . $groupNameObject . " = {'GroupName' => " . $groupName . "};\n" ;
+    my $makeGroup = "my " . $groupNameObject . " = {};\n" ;
     for my $groupElement (@groupElements) {
         $makeGroup .=  $groupNameObject . "->{" . $groupElement . "} = '';\n";
     }
@@ -1891,6 +1908,35 @@ sub PT::EachSymbol::X {
     return $eachSymbol;
 }
 
+sub PT::LBrace::X {
+    my ($class, $className) = @_;
+    my $lBrace = $class->{''};
+    return $lBrace;
+}
+
+sub PT::LBraceError::X {
+    my ($class, $className) = @_;
+    my $lBraceError = $class->{''};
+
+    print "SyntaxError", "\n";
+    print "===========", "\n";
+    die "Missing { after className '", $className, "', instead found ", $lBraceError, "\n";
+}
+
+sub PT::RBrace::X {
+    my ($class, $className) = @_;
+    my $rBrace = $class->{''};
+    return $rBrace;
+}
+
+sub PT::RBraceError::X {
+    my ($class, $className) = @_;
+    my $rBraceError = $class->{''};
+
+    print "SyntaxError", "\n";
+    print "===========", "\n";
+    die "Missing } after class '", $className, "', instead found ", $rBraceError, "\n";
+}
 
 my $parser = qr {
     <nocontext:>
@@ -1899,12 +1945,15 @@ my $parser = qr {
     <Lang>
     <objrule:  PT::Lang>                       <[Class]>+
 
-    <objrule:  PT::Class>                      <TokenClass> <ClassName> <ClassBlock>
+    <objrule:  PT::Class>                      <ws: (\s++)*> <TokenClass> <ClassName> <ClassBlock>
     <objrule:  PT::ClassName>                  [a-zA-Z]+?
-    <objrule:  PT::ClassBlock>                 <LBrace> <ClassGroups> <RBrace>
-    <objrule:  PT::ClassGroups>                <[Group]>+
 
-    <objrule:  PT::Group>                      <ws: (\s++)*> <Comment> | <Parent> | <Packages> | <EmbedBlock>
+    <objrule:  PT::ClassBlock>                 <ErrorLBrace> <ClassGroups> <ErrorRBrace>
+    <objrule:  PT::ErrorLBrace>                <LBrace> | <LBraceError>
+    <objrule:  PT::ErrorRBrace>                <RBrace> | <RBraceError>
+
+    <objrule:  PT::ClassGroups>                <[Group]>+
+    <objrule:  PT::Group>                      <Comment> | <Parent> | <Packages> | <EmbedBlock> | <GroupDeclaration>
                                                | <ImplementFunction> | <Function> | <NonSyntaxClass>
 
     <objtoken: PT::NonSyntaxClass>             \b.*\b
@@ -2015,7 +2064,7 @@ my $parser = qr {
     <objrule:  PT::ClassFunctionCall>          <TokenClass> <Dot> <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
 
     <objrule:  PT::ObjectCall>                 <ObjectFunctionCall> <SemiColon>
-    <objrule:  PT::VariableDeclaration>        <ArrayDeclaration> | <HashDeclaration> | <ScalarDeclaration> | <GroupDeclaration>
+    <objrule:  PT::VariableDeclaration>        <ArrayDeclaration> | <HashDeclaration> | <ScalarDeclaration>
 
     <objrule:  PT::GroupDeclaration>           <TokenGroup> <GroupName> <GroupBlock> <SemiColon>
     <objtoken: PT::GroupName>                  <VariableName>
@@ -2183,7 +2232,9 @@ my $parser = qr {
     <objtoken: PT::LParen>                     \(
     <objtoken: PT::RParen>                     \)
     <objtoken: PT::LBrace>                     \{
+    <objtoken: PT::LBraceError>                \s.
     <objtoken: PT::RBrace>                     \}
+    <objtoken: PT::RBraceError>                \s*.
     <objtoken: PT::LBracket>                   \[
     <objtoken: PT::RBracket>                   \]
 }xms;
